==> haskell-crypton-socks-0.6.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-socks
version:              0.6.2
visibility:           public
id:                   crypton-socks-0.6.2-341tAgDnJjtA561L98BrFU
key:                  crypton-socks-0.6.2-341tAgDnJjtA561L98BrFU
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    Mike Pilgrem <public@pilgrem.com>,
    Kazu Yamamoto <kazu@iij.ad.jp>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/mpilgrem/crypton-socks
synopsis:             SOCKS Protocol Version 5
description:          A library implementing SOCKS Protocol Version 5.
category:             Network
abi:                  edbbfbd28b25936833f540b17a9ccd44
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Command Network.Socks5.Conf Network.Socks5.Parse
    Network.Socks5.Wire

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-socks-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-socks-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-socks-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-socks
hs-libraries:         HScrypton-socks-0.6.2-341tAgDnJjtA561L98BrFU
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    network-3.1.4.0-9SQkdFTpEbMLQxc4pkijnN

haddock-interfaces:
    /usr/share/doc/haskell-crypton-socks/html/crypton-socks.haddock

haddock-html:         /usr/share/doc/haskell-crypton-socks/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-socks-0.6.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-socks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-socks
version:              0.6.2
visibility:           public
id:                   crypton-socks-0.6.2-6PapMqLCsNDExELzYliPj1
key:                  crypton-socks-0.6.2-6PapMqLCsNDExELzYliPj1
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    Mike Pilgrem <public@pilgrem.com>,
    Kazu Yamamoto <kazu@iij.ad.jp>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/mpilgrem/crypton-socks
synopsis:             SOCKS Protocol Version 5
description:          A library implementing SOCKS Protocol Version 5.
category:             Network
abi:                  0a9a9a160e38e30b045650c6589d5f7d
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Command Network.Socks5.Conf Network.Socks5.Parse
    Network.Socks5.Wire

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-socks-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-socks-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-socks-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-socks
hs-libraries:         HScrypton-socks-0.6.2-6PapMqLCsNDExELzYliPj1
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    network-3.1.4.0-GAyMeTMiQBM1z6BFq5KYYA

haddock-interfaces:
    /usr/share/doc/haskell-crypton-socks/html/crypton-socks.haddock

haddock-html:         /usr/share/doc/haskell-crypton-socks/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
